@@ -40,7 +40,7 @@ setMethod(
     plot.df <- cbind(c(seq_len(dim(plot.df)[1])), plot.df)
     names(plot.df) <- c("iteration", cn)
     to.gather <- colnames(plot.df)[2:length(colnames(plot.df))]
-    to.plot <- plot.df %>% tidyr::gather(key = "param", val = "value", tidyr::all_of(to.gather)) %>% tail(-1)
+    to.plot <- plot.df |> tidyr::gather(key = "param", val = "value", tidyr::all_of(to.gather)) |> tail(-1)
     ggplot2::ggplot(data = to.plot) +
       ggplot2::geom_line(mapping = ggplot2::aes(x = .data$iteration, y = .data$value)) +
       ggplot2::facet_wrap(~param, ncol = ncol, scales = "free")
